<!--
 Copyright (c) 2023 Anthony Mugendi
 
 This software is released under the MIT License.
 https://opensource.org/licenses/MIT
-->

# YTilities
A collection of python utilities i get to use often.

## Docs?
See [Read the docs](https://ytilities.readthedocs.io/en/latest/)